<?php

namespace Drupal\widget_type\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Link;
use Drupal\Core\Menu\MenuLinkTreeElement;
use Drupal\Core\Menu\MenuLinkTreeInterface;
use Drupal\Core\Menu\MenuTreeParameters;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Interactive Components controller.
 */
class InteractiveComponents extends ControllerBase {

  /**
   * The menu link tree.
   *
   * @var \Drupal\Core\Menu\MenuLinkTreeElement
   */
  private $menuTree;

  /**
   * InteractiveComponents constructor.
   *
   * @param \Drupal\Core\Menu\MenuLinkTreeInterface $menu_link_tree
   *   The menu link tree service.
   */
  public function __construct(MenuLinkTreeInterface $menu_link_tree) {
    $parameters = new MenuTreeParameters();
    $parameters->setRoot('interactive_components');
    $parameters->setMaxDepth(1);
    $this->menuTree = current($menu_link_tree->load('admin', $parameters));
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('menu.link_tree'));
  }

  /**
   * Controller entry point.
   *
   * @return array
   *   The response render array.
   *
   * @SuppressWarnings(PHPMD.StaticAccess)
   */
  public function __invoke() {
    // Make sure to list all the items in the menu.
    $links = array_map(static function (MenuLinkTreeElement $element) {
      $menu_link = $element->link;
      return [
        'title' => $menu_link->getTitle(),
        'url' => $menu_link->getUrlObject(),
      ];
    }, $this->menuTree->subtree);
    return [
      'intro' => [
        '#type' => 'html_tag',
        '#tag' => 'p',
        '#value' => $this->t(
          'Interactive components are widget instances that are placed in a page. You can create widget instances manually or you can create them directly in the page builder pages.'
        ),
      ],
      'docs' => [
        '#type' => 'html_tag',
        '#tag' => 'p',
        '#value' => $this->t(
          'Watch the 📼 @link 📼 to gain more insight about the widget architecture.',
          [
            '@link' => Link::fromTextAndUrl(
              $this->t('introduction videos'),
              Url::fromUri('https://video.mateuaguilo.com/videos/watch/playlist/d08e8938-8d52-4cb0-9f34-52f73a0d3cda'
              )
            )->toString(),
          ]
        ),
      ],
      'videos' => [
        '#markup' => '<iframe width="560" height="315" sandbox=""',
        '#type' => 'html_tag',
        '#tag' => 'iframe',
        '#attributes' => [
          'src' => 'https://video.mateuaguilo.com/video-playlists/embed/d08e8938-8d52-4cb0-9f34-52f73a0d3cda',
          'frameborder' => 0,
          'allowfullscreen' => TRUE,
          'width' => 560,
          'height' => 315,
          'scrolling' => FALSE,
          'allowtransparency' => TRUE,
          'sandbox' => 'allow-same-origin allow-scripts allow-popups',
        ],
      ],
      'types' => [
        '#type' => 'html_tag',
        '#tag' => 'p',
        '#value' => $this->t(
          'Each widget instance is has a widget type, or widget definition. Widget definitions are created outside of Drupal by ingesting them from the widget registry using the %link module.',
          [
            '%link' => Link::fromTextAndUrl(
              $this->t('Widget Ingestion'),
              Url::fromUri('https://www.drupal.org/project/widget_ingestion')
            )->toString(),
          ]
        ),
      ],
      'links' => [
        '#theme' => 'links',
        '#links' => $links,
      ],
    ];
  }

}
